@@ -47,6 +47,6 @@ fib.R=function(n=defaultN, len=defaultLen){
 
 #initialization for testing
 fib.init=function(){
-  defaultN<<-200
-  defaultLen<<-10
+  defaultN <- 200; tput(defaultN)
+  defaultLen <- 10; tput(defaultLen)
 }
\ No newline at end of file
